@@ -3,7 +3,7 @@
 ##############################################################################
 ##
 ##  Canon Inkjet Printer Driver for Linux
-##  Copyright CANON INC. 2001-2021
+##  Copyright CANON INC. 2001-2023
 ##
 ##  This program is free software; you can redistribute it and/or modify
 ##  it under the terms of the GNU General Public License as published by
@@ -20,11 +20,11 @@
 ##
 ##############################################################################
 
-C_version="6.30-1"
-C_copyright_end="2021"
+C_version="6.60-1"
+C_copyright_end="2023"
 C_default_system="deb"
 
-P_support_printer=("TS5350I" "G600" "G500" "TS3500" "TR4600" "E4500" "TR4700" "XK500" "TS8530" "XK100" "TS7530" "TS7450I")
+P_support_printer=("G3070" "G2070" "G4070" "G1030" "G3030" "G2030")
 
 L_INST_COM_01_01="Command executed = %s\n"
 
